@@ -1,11 +1,11 @@
 import buildflaskapp
 from buildflaskapp.scripts.workflow import get_app_name, is_name_valid
-from scripts.workflow import get_args,  is_args_valid
-from scripts.workflow import create_dir, create_app, create_templates_folder, create_static_folder, create_dockerfile
-from scripts.manual import print_manual
-from scripts.messages import empty_name, success_msg, failure_msg
-from scripts.workflow import create_requirements_txt
-from scripts.__version__ import __version__
+from buildflaskapp.scripts.workflow import get_args,  is_args_valid
+from buildflaskapp.scripts.workflow import create_dir, create_app, create_templates_folder, create_static_folder, create_dockerfile
+from buildflaskapp.scripts.workflow import create_requirements_txt
+from buildflaskapp.scripts.manual import print_manual
+from buildflaskapp.scripts.messages import empty_name, success_msg, failure_msg
+from buildflaskapp.scripts.__version__ import __version__
 import sys
 
 app_name = get_app_name()
